@@ -90,11 +90,10 @@ void QvkRegionChoise::slot_init()
 #endif
 
 #ifdef Q_OS_WIN
-    // Für das anzeigen der Bereichsanzeige auf dem Bildschirm wird der Index aus einer unsortierten Liste benötigt.
     if ( ui->comboBoxScreencastScreenArea->currentIndex() > -1 ) {
         int index = 0;
         QString nameDisplay = ui->comboBoxScreencastScreenArea->currentText().section( ":", 0, 0 ).trimmed();
-        QList<QScreen *> screenList = QGuiApplication::screens(); // unsortiert
+        QList<QScreen *> screenList = QGuiApplication::screens();
         for ( int i=0; i < screenList.count(); i++ ) {
             QString nameList = screenList.at(i)->name().remove( "." ).remove( "\\" ) ;
             if ( nameDisplay == nameList ) {
@@ -1002,9 +1001,9 @@ void QvkRegionChoise::mouseMoveEvent( QMouseEvent *event )
 
 void QvkRegionChoise::printSize( QPainter &painter )
 {
-  QString widthHeigtSize = QString::number( static_cast<int>( getWidth()/screen->devicePixelRatio() ) ) +
+  QString widthHeigtSize = QString::number( static_cast<int>( getWidth() ) ) +
                            " x " +
-                           QString::number( static_cast<int>( getHeight()/screen->devicePixelRatio() ) );
+                           QString::number( static_cast<int>( getHeight() ) );
 
   QFont font;
   font.setPointSize( 14 );
@@ -1117,9 +1116,9 @@ void QvkRegionChoise::HandleTopLeftSize( QPainter &painter)
     painter.setBrush( QBrush( HandleColorBackgroundSize, Qt::SolidPattern ) );
     painter.setPen( QPen( Qt::black, 2 ) );
     painter.drawRoundedRect( rect, 5, 5 );
-    painter.drawText( rect, Qt::AlignCenter, "x:" + QString::number( frame_X + framePenHalf + 1 ) +
+    painter.drawText( rect, Qt::AlignCenter, "x:" + QString::number( static_cast<int>(( frame_X + framePenHalf ) * screen->devicePixelRatio()) ) +
                                              "\n" +
-                                             "y:" + QString::number( frame_Y + framePenHalf + 1 ) );
+                                             "y:" + QString::number( static_cast<int>(( frame_Y + framePenHalf ) * screen->devicePixelRatio()) ) );
 }
 
 
@@ -1168,7 +1167,7 @@ void QvkRegionChoise::HandleTopMiddleSize( QPainter &painter )
     painter.setBrush( QBrush( HandleColorBackgroundSize, Qt::SolidPattern ) );
     painter.setPen( QPen( Qt::black, 2 ) );
     painter.drawRoundedRect( rect, 5, 5 );
-    painter.drawText( rect, Qt::AlignCenter, "y:" + QString::number( frame_Y + framePenHalf + 1 ) );
+    painter.drawText( rect, Qt::AlignCenter, "y:" + QString::number( static_cast<int>(( frame_Y + framePenHalf ) * screen->devicePixelRatio()) ) );
 }
 
 
@@ -1217,9 +1216,9 @@ void QvkRegionChoise::HandleTopRightSize( QPainter &painter )
     painter.setBrush( QBrush( HandleColorBackgroundSize, Qt::SolidPattern ) );
     painter.setPen( QPen( Qt::black, 2 ) );
     painter.drawRoundedRect( rect, 5, 5 );
-    painter.drawText( rect, Qt::AlignCenter, "x:" + QString::number( frame_X + frame_Width - framePenHalf ) +
+    painter.drawText( rect, Qt::AlignCenter, "x:" + QString::number( static_cast<int>(( frame_X + frame_Width - framePenHalf ) * screen->devicePixelRatio() )) +
                                              "\n" +
-                                             "y:" + QString::number( frame_Y + framePenHalf + 1 ) );
+                                             "y:" + QString::number( static_cast<int>((frame_Y + framePenHalf ) * screen->devicePixelRatio()) ) );
 }
 
 
@@ -1268,7 +1267,7 @@ void QvkRegionChoise::HandleRightMiddleSize( QPainter &painter )
     painter.setBrush( QBrush( HandleColorBackgroundSize, Qt::SolidPattern ) );
     painter.setPen( QPen( Qt::black, 2 ) );
     painter.drawRoundedRect( rect, 5, 5 );
-    painter.drawText( rect, Qt::AlignCenter, "x:" + QString::number( frame_X + frame_Width - framePenHalf) );
+    painter.drawText( rect, Qt::AlignCenter, "x:" + QString::number( static_cast<int>( (frame_X + frame_Width - framePenHalf ) * screen->devicePixelRatio()) ) );
 }
 
 
@@ -1318,9 +1317,9 @@ void QvkRegionChoise::HandleBottomRightSize( QPainter &painter )
     painter.setBrush( QBrush( HandleColorBackgroundSize, Qt::SolidPattern ) );
     painter.setPen( QPen( Qt::black, 2 ) );
     painter.drawRoundedRect( rect, 5, 5 );
-    painter.drawText( rect, Qt::AlignCenter, "x:" + QString::number( frame_X + frame_Width - framePenHalf ) +
+    painter.drawText( rect, Qt::AlignCenter, "x:" + QString::number( static_cast<int>( ( frame_X + frame_Width - framePenHalf ) * screen->devicePixelRatio() ) ) +
                                              "\n" +
-                                             "y:" + QString::number( frame_Y + frame_height - framePenHalf ) );
+                                             "y:" + QString::number( static_cast<int>( ( frame_Y + frame_height - framePenHalf ) * screen->devicePixelRatio() ) ) );
 }
 
 
@@ -1370,7 +1369,7 @@ void QvkRegionChoise::HandleBottomMiddleSize(QPainter &painter )
     painter.setBrush( QBrush( HandleColorBackgroundSize, Qt::SolidPattern ) );
     painter.setPen( QPen( Qt::black, 2 ) );
     painter.drawRoundedRect( rect, 5, 5 );
-    painter.drawText( rect, Qt::AlignCenter, "y:" + QString::number( frame_Y + frame_height - framePenHalf ) );
+    painter.drawText( rect, Qt::AlignCenter, "y:" + QString::number( static_cast<int>( ( frame_Y + frame_height - framePenHalf ) * screen->devicePixelRatio() ) ) );
 }
 
 
@@ -1419,9 +1418,9 @@ void QvkRegionChoise::HandleBottomLeftSize( QPainter &painter )
     painter.setBrush( QBrush( HandleColorBackgroundSize, Qt::SolidPattern ) );
     painter.setPen( QPen( Qt::black, 2 ) );
     painter.drawRoundedRect( rect, 5, 5 );
-    painter.drawText( rect, Qt::AlignCenter, "x:" + QString::number( frame_X + framePenHalf + 1 ) +
+    painter.drawText( rect, Qt::AlignCenter, "x:" + QString::number( static_cast<int>( ( frame_X + framePenHalf ) * screen->devicePixelRatio() ) ) +
                                              "\n" +
-                                             "y:" + QString::number( frame_Y + frame_height - framePenHalf ) );
+                                             "y:" + QString::number( static_cast<int>( ( frame_Y + frame_height - framePenHalf ) * screen->devicePixelRatio()) ));
 }
 
 
@@ -1470,7 +1469,7 @@ void QvkRegionChoise::HandleLeftMiddleSize( QPainter &painter )
     painter.setBrush( QBrush( HandleColorBackgroundSize, Qt::SolidPattern ) );
     painter.setPen( QPen( Qt::black, 2 ) );
     painter.drawRoundedRect( rect, 5, 5 );
-    painter.drawText( rect, Qt::AlignCenter, "x:" + QString::number( frame_X + framePenHalf + 1 ) );
+    painter.drawText( rect, Qt::AlignCenter, "x:" + QString::number( static_cast<int>( ( frame_X + framePenHalf ) * screen->devicePixelRatio() ) ) );
 }
 
 
@@ -1580,48 +1579,20 @@ qreal QvkRegionChoise::getYRecordArea()
 /**
  * Return height from record area
  */
-qreal QvkRegionChoise::getHeight()
+int QvkRegionChoise::getHeight()
 {
-    qreal xReal =   ( ( frame_Y + framePenWidth/2 ) + ( frame_height - framePenWidth ) ) * screen->devicePixelRatio();
-    int xInt = static_cast<int>( ( ( frame_Y + framePenWidth/2 ) + ( frame_height - framePenWidth ) ) * screen->devicePixelRatio() );
-
-    if ( xReal > xInt ) {
-        xReal = static_cast<int>( ( frame_height - framePenWidth ) * screen->devicePixelRatio() ) - 1;
-    } else {
-        xReal = static_cast<int>( ( frame_height - framePenWidth ) * screen->devicePixelRatio() );
-    }
-
-#ifdef Q_OS_WIN
-    if ( ( xReal + getYRecordArea() ) == screen->size().height() ) {
-      xReal-=2;
-    }
-#endif
-
-    return xReal;
+    int yInt = ( frame_height - framePenWidth ) * screen->devicePixelRatio();
+    return yInt;
 }
 
 
 /**
  * Return width from record Area
  */
-qreal QvkRegionChoise::getWidth()
+int QvkRegionChoise::getWidth()
 {
-    qreal xReal = ( ( frame_X + framePenWidth/2 ) + ( frame_Width - framePenWidth ) ) * screen->devicePixelRatio();
-    int xInt = static_cast<int>( ( ( frame_X + framePenWidth/2 ) + ( frame_Width - framePenWidth ) ) * screen->devicePixelRatio() );
-
-    if ( xReal > xInt ) {
-        xReal = static_cast<int>( ( frame_Width - framePenWidth ) * screen->devicePixelRatio() ) - 1;
-    } else {
-        xReal = static_cast<int>( ( frame_Width - framePenWidth ) * screen->devicePixelRatio() );
-    }
-
-#ifdef Q_OS_WIN
-    if ( ( xReal + getXRecordArea() ) == screen->size().width() ) {
-      xReal-=2;
-    }
-#endif
-
-    return xReal;
+    int xInt = ( frame_Width - framePenWidth ) * screen->devicePixelRatio();
+    return xInt;
 }
 
 
