@@ -375,7 +375,8 @@ void QvkMainWindow_wl::set_Connects()
     connect( ui->pushButtonStart, SIGNAL( clicked(bool) ), ui->frame_video,                     SLOT( setEnabled(bool) ) );
     connect( ui->pushButtonStart, SIGNAL( clicked(bool) ), ui->frame_audio,                     SLOT( setEnabled(bool) ) );
     connect( ui->pushButtonStart, SIGNAL( clicked(bool) ), ui->frame_3,                         SLOT( setEnabled(bool) ) );
-//    connect( ui->pushButtonStart, SIGNAL( clicked(bool) ), this,                                SLOT( slot_portal_start() ) );
+    connect( ui->pushButtonStart, &QPushButton::clicked, vkRegionMargins_wl, [=]() { vkRegionMargins_wl->whatWasClicked = "pushButtonStart" ; } );
+    connect( ui->pushButtonStart, &QPushButton::clicked, this,               [=]() { whatWasClicked = "pushButtonStart" ; } );
     connect( ui->pushButtonStart, SIGNAL( clicked(bool) ), this,                                SLOT( slot_pre_portal_start() ) );
     connect( vkRegionMargins_wl,  SIGNAL( signal_regionMargins() ), this,                       SLOT( slot_portal_start() ) );
 
@@ -428,6 +429,8 @@ void QvkMainWindow_wl::set_Connects()
     connect( ui->toolButtonFramesReset,         SIGNAL( clicked(bool) ), this,              SLOT( slot_frames_Reset() ) );
     connect( ui->toolButtonOpenh264Reset,       SIGNAL( clicked(bool) ), this,              SLOT( slot_openh264Reset() ) );
 
+    connect( ui->pushButtonSnapshot, &QPushButton::clicked, vkRegionMargins_wl, [=]() { vkRegionMargins_wl->whatWasClicked = "pushButtonSnapshot" ; } );
+    connect( ui->pushButtonSnapshot, &QPushButton::clicked, this,               [=]() { whatWasClicked = "pushButtonSnapshot" ; } );
     connect( ui->pushButtonSnapshot,           SIGNAL( clicked(bool) ), this, SLOT( slot_snapshotHideBeforeRecording(bool) ) );
     connect( ui->pushButtonSnapshotOpenFolder, SIGNAL( clicked(bool) ), this, SLOT( slot_path_to_snapshot_folder(bool) ) );
     connect( ui->toolButtonSnapshotFormatsReset, &QPushButton::clicked, this, [=]() {
@@ -438,9 +441,6 @@ void QvkMainWindow_wl::set_Connects()
     connect( ui->toolButtonSnapshotSecondsWaitBeforeRecordingReset, &QPushButton::clicked, this, [=]() {
         spezialSlider->setValue(4); } );
 
-
-
-
     connect( ui->pushButton_log_openfolder, SIGNAL( clicked(bool) ), this, SLOT( slot_log_folder() ) );
     connect( ui->pushButton_log_refresh,    SIGNAL( clicked(bool) ), this, SLOT( slot_log_refresh() ) );
 }
@@ -491,27 +491,34 @@ void QvkMainWindow_wl::slot_handle_response_snapshot( uint responseCode, QVarian
         path_to_snapshot_folder = fileInfo.absolutePath();
         QString filePath_org = fileInfo.absoluteFilePath();
 
-        QPixmap pixmap = QPixmap( filePath_org );
-        QString filePath_new = path_to_snapshot_folder +
-                "/" +
-                global::name +
-                "-" +
-                QDateTime::currentDateTime().toString( "yyyy-MM-dd_hh-mm-ss.zzz" ) +
-                "." +
-                ui->comboBoxSnapshotImageFormats->currentText().toUtf8();
-        pixmap.save( filePath_new );
+        if ( filePath_org > "" ) {
+            if ( whatWasClicked == "pushButtonSnapshot" ) {
+                QPixmap pixmap = QPixmap( filePath_org );
+                QString filePath_new = path_to_snapshot_folder +
+                        "/" +
+                        global::name +
+                        "-" +
+                        QDateTime::currentDateTime().toString( "yyyy-MM-dd_hh-mm-ss.zzz" ) +
+                        "." +
+                        ui->comboBoxSnapshotImageFormats->currentText().toUtf8();
+                pixmap.save( filePath_new );
 
-        QFile file( filePath_org );
-        file.remove();
+                QFile file( filePath_org );
+                file.remove();
 
-        QvkShowMessage_wl *vkShowMessage_wl = new QvkShowMessage_wl();
-        vkShowMessage_wl->set_StatusIcon( ":/pictures/status/information.png" );
-        vkShowMessage_wl->set_Image( filePath_new );
-        vkShowMessage_wl->set_timeOut( 10000 );
-        vkShowMessage_wl->showMessage( "" );
-        vkShowMessage_wl->set_folderPath( path_to_snapshot_folder );
+                if ( ui->checkBoxSnapshotShowBallonInSystray->isChecked() == true ) {
+                    QvkShowMessage_wl *vkShowMessage_wl = new QvkShowMessage_wl();
+                    vkShowMessage_wl->set_StatusIcon( ":/pictures/status/information.png" );
+                    vkShowMessage_wl->set_Image( filePath_new );
+                    vkShowMessage_wl->set_timeOut( 10000 );
+                    vkShowMessage_wl->showMessage( "" );
+                    vkShowMessage_wl->set_WindowTitle( "Snapshot" );
+                    vkShowMessage_wl->set_folderPath( path_to_snapshot_folder );
+                }
 
-        qDebug().noquote() << global::nameOutput << "[Snapshot] Saved under:" << filePath_new;
+                qDebug().noquote() << global::nameOutput << "[Snapshot] Saved under:" << filePath_new;
+            }
+        }
     } else {
         qDebug().noquote() << global::nameOutput << "[Snapshot] Unable to take a screenshot" << results["uri"];
     }
@@ -575,6 +582,8 @@ void QvkMainWindow_wl::supportedImageFormats()
 
 void QvkMainWindow_wl::slot_pre_portal_start()
 {
+    qDebug().noquote() << global::nameOutput << "[QvkMainWindow_wl] slot_pre_portal_start()";
+
     if ( ui->radioButtonScreencastArea->isChecked() ) {
         vkRegionMargins_wl->setVisible(true);
         vkRegionMargins_wl->slot_singleShot(true);
@@ -587,8 +596,6 @@ void QvkMainWindow_wl::slot_pre_portal_start()
     if ( ui->radioButtonScreencastFullscreen->isChecked() ) {
         slot_portal_start();
     }
-
-    qDebug().noquote() << global::nameOutput << "[QvkMainWindow_wl] slot_pre_portal_start()";
 }
 
 
